#ifndef NT2_INCLUDE_FUNCTIONS_FROMPOLAR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FROMPOLAR_HPP_INCLUDED

#include <nt2/complex/include/functions/frompolar.hpp>

#endif
